@@ -1,11 +1,12 @@
-from eth_keys import (
-    keys,
-)
-from eth_keys.tools.factories import (
+from tools.factories import (
     PrivateKeyFactory,
     PublicKeyFactory,
 )
 
+from eth_keys import (
+    keys,
+)
+
 
 def test_private_key_factory():
     actual = PrivateKeyFactory()
